assert_text_contains

Macro assert_text_contains 

macro_rules! assert_text_contains {
    ($left: expr, $right: expr $(,)?) => { ... };
    ($left: expr, $right: expr, $($arg:tt)+) => { ... };
}
Asserts that the first text contains the given second text.

If the text does not contains second text, it panics.

Arguments

  • $left - The text expression to check.
  • $right - The second text expression.

Examples

use assert_text::assert_text_contains;
assert_text_contains!("hello world", "o w");
use assert_text::assert_text_contains;
assert_text_contains!("hello world", "apple");
use assert_text::assert_text_contains;
assert_text_contains!("hello world", "apple", "custom message: {}", "foo");